==> dotnet8_8.0.120-8.0.20.orig.tar.xz: src/razor/src/Compiler/Microsoft.AspNetCore.Razor.Language/test/Extensions/DefaultMetadataIdentifierFeatureTest.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using Xunit;

namespace Microsoft.AspNetCore.Razor.Language.Extensions;

public class DefaultMetadataIdentifierFeatureTest : RazorProjectEngineTestBase
{
    protected override RazorLanguageVersion Version => RazorLanguageVersion.Latest;

    [Fact]
    public void GetIdentifier_ReturnsNull_ForNullRelativePath()
    {
        // Arrange
        var sourceDocument = RazorSourceDocument.Create("content", new RazorSourceDocumentProperties("Test.cshtml", null));
        var codeDocument = RazorCodeDocument.Create(sourceDocument);

        var feature = new DefaultMetadataIdentifierFeature()
        {
            Engine = CreateProjectEngine().Engine,
        };

        // Act
        var result = feature.GetIdentifier(codeDocument, sourceDocument);

        // Assert
        Assert.Null(result);
    }

    [Fact]
    public void GetIdentifier_ReturnsNull_ForEmptyRelativePath()
    {
        // Arrange
        var sourceDocument = RazorSourceDocument.Create("content", new RazorSourceDocumentProperties("Test.cshtml", string.Empty));
        var codeDocument = RazorCodeDocument.Create(sourceDocument);

        var feature = new DefaultMetadataIdentifierFeature()
        {
            Engine = CreateProjectEngine().Engine,
        };

        // Act
        var result = feature.GetIdentifier(codeDocument, sourceDocument);

        // Assert
        Assert.Null(result);
    }

    [Theory]
    [InlineData("Test.cshtml", "/Test.cshtml")]
    [InlineData("/Test.cshtml", "/Test.cshtml")]
    [InlineData("\\Test.cshtml", "/Test.cshtml")]
    [InlineData("\\About\\Test.cshtml", "/About/Test.cshtml")]
    [InlineData("\\About\\Test\\cshtml", "/About/Test/cshtml")]
    public void GetIdentifier_SanitizesRelativePath(string relativePath, string expected)
    {
        // Arrange
        var sourceDocument = RazorSourceDocument.Create("content", new RazorSourceDocumentProperties("Test.cshtml", relativePath));
        var codeDocument = RazorCodeDocument.Create(sourceDocument);

        var feature = new DefaultMetadataIdentifierFeature()
        {
            Engine = CreateProjectEngine().Engine,
        };

        // Act
        var result = feature.GetIdentifier(codeDocument, sourceDocument);

        // Assert
        Assert.Equal(expected, result);
    }
}

==> dotnet9_9.0.110-9.0.9.orig.tar.xz: src/razor/src/Compiler/Microsoft.AspNetCore.Razor.Language/test/Extensions/DefaultMetadataIdentifierFeatureTest.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

#nullable disable

using Xunit;

namespace Microsoft.AspNetCore.Razor.Language.Extensions;

public class DefaultMetadataIdentifierFeatureTest : RazorProjectEngineTestBase
{
    protected override RazorLanguageVersion Version => RazorLanguageVersion.Latest;

    [Fact]
    public void GetIdentifier_ReturnsNull_ForNullRelativePath()
    {
        // Arrange
        var sourceDocument = RazorSourceDocument.Create("content", RazorSourceDocumentProperties.Create("Test.cshtml", null));
        var codeDocument = RazorCodeDocument.Create(sourceDocument);

        var feature = new DefaultMetadataIdentifierFeature()
        {
            Engine = CreateProjectEngine().Engine,
        };

        // Act
        var result = feature.GetIdentifier(codeDocument, sourceDocument);

        // Assert
        Assert.Null(result);
    }

    [Fact]
    public void GetIdentifier_ReturnsNull_ForEmptyRelativePath()
    {
        // Arrange
        var sourceDocument = RazorSourceDocument.Create("content", RazorSourceDocumentProperties.Create("Test.cshtml", string.Empty));
        var codeDocument = RazorCodeDocument.Create(sourceDocument);

        var feature = new DefaultMetadataIdentifierFeature()
        {
            Engine = CreateProjectEngine().Engine,
        };

        // Act
        var result = feature.GetIdentifier(codeDocument, sourceDocument);

        // Assert
        Assert.Null(result);
    }

    [Theory]
    [InlineData("Test.cshtml", "/Test.cshtml")]
    [InlineData("/Test.cshtml", "/Test.cshtml")]
    [InlineData("\\Test.cshtml", "/Test.cshtml")]
    [InlineData("\\About\\Test.cshtml", "/About/Test.cshtml")]
    [InlineData("\\About\\Test\\cshtml", "/About/Test/cshtml")]
    public void GetIdentifier_SanitizesRelativePath(string relativePath, string expected)
    {
        // Arrange
        var sourceDocument = RazorSourceDocument.Create("content", RazorSourceDocumentProperties.Create("Test.cshtml", relativePath));
        var codeDocument = RazorCodeDocument.Create(sourceDocument);

        var feature = new DefaultMetadataIdentifierFeature()
        {
            Engine = CreateProjectEngine().Engine,
        };

        // Act
        var result = feature.GetIdentifier(codeDocument, sourceDocument);

        // Assert
        Assert.Equal(expected, result);
    }
}
